<!-- ;; ---------------------------------------------------------------------- -->
<!-- ;; Created: fre jul 17 19:11:39 2020 (+0200) -->
<!-- ;; Last-Updated: sön jun 20 11:37:44 2021 (+0200)
<!-- ;; Filename: README.md -->
<!-- ;; Author: Yinan Yu -->
<!-- ;; Description:  -->
<!-- ;; ---------------------------------------------------------------------- -->



---
**Stay tuned!**
More examples and documentation to come

---
# Alex - a neural network analyzer

<img src="https://github.com/yinan16/alex/blob/master/images/logo.png" width="150" alt="Alex logo" title="Alex">

Alex is a Domain Specific Language (DSL) for declaring, representing, analyzing and generating neural networks.
This DSL can be considered as a configuration file to define a neural network.

### How to install:
+ `pip install alex-nn`

## How to run

### Command Line Interface
`alex-nn`

### Python

## Motivation

### Alex the little chef
Deep learning is like cooking. You have a bunch of ingredients and you put them in a pot. You have some intuitions and somewhat limited theoretical understanding of why this soup tastes better than that one, but you don't really know what's going on. Alex is a little chef that helps you distill and refine your networks. Alex is committed to helping you find better recipes for your use case.

### What does Alex do?
